==> aroundme_0_3_3.tar: aroundme_0_3_3/www/aroundme_0_3_3/language/1/am_default/sn_invite.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
// 
// Copyright (C) 2003, 2004 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
// 
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
// 
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------

require_once($languagePath . 'common_sn.lang.php');
/*
* All language vars should be ordered TYPE, A-Z for convenience
* Tom Calthrop - 20th April 2004 (tom@barnraiser.org)
*/

//section titles
$lang['section_sent'] = 						"sent";


//HEADER
$lang['hdr_im_pending'] = 						"pending requests";
$lang['hdr_invite'] = 							"invite your friends!";
$lang['hdr_invite_notes'] = 					"customise the email";


//SUBMIT BUTTONS
$lang['sub_invite'] = 							"INVITE NOW!";


//ERRORS
$lang['err_no_pending_requests'] = 				"No pending requests.";


//BODY TEXT
$lang['txt_emails_sent'] =						"emails sent";
$lang['txt_invite'] =							"You have been invited into Barnraiser!";
$lang['txt_invite_message_help'] =				"You can change the text if you want.";
$lang['txt_invite_message_txt'] =				"Join me in Barnraiser!";
$lang['txt_invite_subject_help'] =				"You can change the subject if you want.";
$lang['txt_invite_to_help'] =					"You can either put each email address on a new line or use a comma (,) between them like 'support@barnraiser.org, info@barnraiser.org'. Please don't send more than 25 emails at a time.";
$lang['txt_invite_help'] = 						"Got friends who aren't here? Whoa, you hang around with some unconnected folk - help them, invite them in. Grow your social network and be the hub of your social scene.<p>Simply type in their email addresses and press 'INVITE NOW!'.";

?>

==> aroundme_0_4_1.tar: aroundme_0_4_1/www/aroundme_0_4_1/language/1/am_default/sn_invite.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
// 
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
// 
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
// 
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------

require_once($languagePath . 'sn_common.lang.php');
/*
* All language vars should be ordered TYPE, A-Z for convenience
* Tom Calthrop - 20th April 2004 (tom@barnraiser.org)
*/

//section titles
$lang['section_sent'] = 						"sent";


//HEADER
$lang['hdr_im_pending'] = 						"pending requests";
$lang['hdr_invite'] = 							"invite your friends!";
$lang['hdr_invite_notes'] = 					"customise the email";


//SUBMIT BUTTONS
$lang['sub_invite'] = 							"INVITE NOW!";


//ERRORS
$lang['err_no_pending_requests'] = 				"No pending requests.";


//BODY TEXT
$lang['txt_emails_sent'] =						"emails sent";
$lang['txt_invite'] =							"You have been invited into Barnraiser!";
$lang['txt_invite_message_help'] =				"You can change the text if you want.";
$lang['txt_invite_message_txt'] =				"Join me in Barnraiser!";
$lang['txt_invite_subject_help'] =				"You can change the subject if you want.";
$lang['txt_invite_to_help'] =					"You can either put each email address on a new line or use a comma (,) between them like 'support@barnraiser.org, info@barnraiser.org'. Please don't send more than 25 emails at a time.";
$lang['txt_invite_help'] = 						"Got friends who aren't here? Whoa, you hang around with some unconnected folk - help them, invite them in. Grow your social network and be the hub of your social scene.<p>Simply type in their email addresses and press 'INVITE NOW!'.";

?>
